<template>
    <div>
        <q-input hide-bottom-space :color="tableColor" dense v-model="dateRangeDisplay" mask="##-##-#### to ##-##-####"
            fill-mask unmasked-value style="min-width: 200px">
            <template v-slot:append>
                <q-icon name="event" class="cursor-pointer">
                    <q-popup-proxy ref="qDateProxy" transition-show="scale" transition-hide="scale">
                        <q-date v-model="dateRangeDisplay" mask="YYYY-MM-DD" range
                            :color="this.$store.state.app.color + '-4'" />
                    </q-popup-proxy>
                </q-icon>
            </template>
        </q-input>
    </div>
</template>

<script>
const { date } = Quasar
export default {
    watch: {
        date_: {
            handler(val) {
                this.$emit('update:modelValue', val)
            },
            deep: true
        },
        modelValue: {
            handler(val) {
                console.log('watch', val)
                this.date_ = Object.assign(this.date_, val)
            },
            deep: true
        }
    },
    props: ['modelValue'],
    data() {
        return {
            date_: {
                from: null,
                to: null
            }
        }
    },
    computed: {
        dateRangeDisplay: {
            get: function () {
                console.log('compute', this.date_)
                if (this.date_ !== null && this.date_.from !== null & this.date_.to !== null) {
                    return date.formatDate(this.date_.from, 'DDMMYYYY') + '' + date.formatDate(this.date_.to, 'DDMMYYYY')
                }
                return ''
            },
            set: function (range) {
                if (range === undefined) {
                    this.date_.from = null
                    this.date_.to = null
                } else {
                    if (range?.from !== undefined && range?.to !== undefined) {
                        this.date_.from = range.from
                        this.date_.to = range.to
                    } else {
                        this.date_.from = range
                        this.date_.to = range
                    }
                }
            }
        }
    }
}
</script>